Stan Math Library: stan/math/prim/scal/fun/primitive_value.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
primitive_value.hpp File Reference
`#include <boost/utility/enable_if.hpp>`
`#include <boost/type_traits/is_arithmetic.hpp>`
`#include <stan/math/prim/scal/fun/value_of.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
boost::enable_if< boost::is_arithmetic< T >, T >::type | stan::math::primitive_value (T x)
| Return the value of the specified arithmetic argument unmodified with its own declared type. More...
template<typename T >
boost::disable_if< boost::is_arithmetic< T >, double >::type | stan::math::primitive_value (const T &x)
| Return the primitive value of the specified argument. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.